@@ -3,7 +3,7 @@ VERSION='0.3.2'
 #
 # Copyright (C) 2002       Mark Lawrence <nomad@null.net>
 # Copyright (C) 2002       Paul Sladen   <vserver@paul.sladen.org>
-# Copyright (C) 2002, 2004 Ola Lundqvist <opal@debian.org>
+# Copyright (C) 2002-2005  Ola Lundqvist <opal@debian.org>
 #
 # This is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free
@@ -40,7 +40,7 @@ EXTRA_PACKAGES=""
 
 # Packages to remove from the base defaults (seperated by "," commas)
 #REMOVE_PACKAGES="dhcp-client,lilo,makedev,pcmcia-cs,ppp,pppconfig,pppoe,pppoeconf,setserial,syslinux,nano,fdutils,iptables,libpcap0,pciutils"
-REMOVE_PACKAGES="sparc-utils,dhcp-client,lilo,makedev,pcmcia-cs,ppp,pppconfig,pppoe,pppoeconf,setserial,syslinux,fdutils,iptables,libpcap0,pciutils"
+REMOVE_PACKAGES="sparc-utils,dhcp-client,lilo,makedev,pcmcia-cs,ppp,pppconfig,pppoe,pppoeconf,setserial,syslinux,fdutils,libpcap0,iptables,pciutils"
 
 # sysvinit services relating to hardware access to remove
 REMOVE_LINKS="klogd hwclock.sh setserial urandom networking umountfs halt reboot"
@@ -73,6 +73,11 @@ if [ -r /etc/vservers/newvserver-vars ] ; then
     . /etc/vservers/newvserver-vars    
 fi
 
+# Support for 0.30.203 and above of util-vserver
+if [ -n "$DEFAULT_VSERVERDIR" ] ; then
+    VROOTDIR="$DEFAULT_VSERVERDIR"
+fi
+
 # ----------------------------------------------------------------
 # Nothing from here on should need changing.
 # ----------------------------------------------------------------
@@ -113,7 +118,7 @@ Required:
 	--domain		dns domain for new vserver (eg. "example.com")
 	--ip			IPv4 address for new vserver
 
-You can also set variables in /etc/vservers/vserver-vars.
+You can also set variables in /etc/vservers/newvserver-vars.
 
 EOF
 }
@@ -121,9 +126,9 @@ full_version ()
 {
     cat << EOF
 ${0##*/} version $VERSION
-Copyright (c) 2002 Mark Lawrence <nomad@null.net>
-Copyright (c) 2002 Paul Sladen   <vserver@paul.sladen.org>
-Copyright (c) 2003 Ola Lundqvist <opal@debian.org>
+Copyright (c) 2002      Mark Lawrence <nomad@null.net>
+Copyright (c) 2002      Paul Sladen   <vserver@paul.sladen.org>
+Copyright (c) 2002-2005 Ola Lundqvist <opal@debian.org>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -262,7 +267,7 @@ parse_args ()
 			;;
 		    --mirror)
 			case "$2" in
-			    [hf]*://*)
+			    [hf]*:/*)
 				MIRROR="$2"
 				;;
 			    *)
@@ -372,7 +377,7 @@ fi
 # This is used to keep a cache of the downloaded .deb packges for next install
 if [ -d "$VROOTDIR/ARCHIVES/$DIST" ]; then
     mkdir -p "$VROOTDIR/$VHOST/var/cache/apt/archives"
-    cp -a "$VROOTDIR/ARCHIVES/$DIST/"*.deb "$VROOTDIR/$VHOST/var/cache/apt/archives"
+    cp -a "$VROOTDIR/ARCHIVES/$DIST/"*.deb "$VROOTDIR/$VHOST/var/cache/apt/archives" > /dev/null 2>&1
 fi
 
 # We only want to pass the Architecture if we need to (autodectected otherwise)
@@ -579,11 +584,13 @@ dpkg-reconfigure passwd
 
 tasksel
 
-rm -f /etc/exim/exim.conf
-eximconfig
+if [ "$DIST" == "woody" ]; then
+    rm -f /etc/exim/exim.conf
+    eximconfig
+fi
 
 # because the --exclude flag doesn\'t seem to work on debootstrap
-apt-get --assume-yes --purge remove `echo $REMOVE_PACKAGES | sed -e 's/,/ /g'`
+dpkg -P `echo $REMOVE_PACKAGES | sed -e 's/,/ /g'`
 
 for link in $REMOVE_LINKS
 do
@@ -616,7 +623,7 @@ if [ -f "$SSH_KEYS" ]; then
 fi
 
 # Install the vreboot/rebootmgr utility--hopefully this will disappear soon
-VREBOOT_LOCATION="/usr/lib/vserver/vreboot"
+VREBOOT_LOCATION="/usr/lib/util-vserver/vreboot"
 if [ "$COPY_VREBOOT" == "true" -a -x "$VREBOOT_LOCATION" ]; then
     cp -a "$VREBOOT_LOCATION" "$VROOTDIR/$VHOST/usr/local/sbin/"
     chmod 750 "$VROOTDIR/$VHOST/usr/local/sbin/vreboot"
